/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Intercom from "../../../index";
export declare namespace Contacts {
    interface Options {
        environment?: core.Supplier<environments.IntercomEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the Intercom-Version header */
        version?: "1.0" | "1.1" | "1.2" | "1.3" | "1.4" | "2.0" | "2.1" | "2.2" | "2.3" | "2.4" | "2.5" | "2.6" | "2.7" | "2.8" | "2.9" | "2.10" | "2.11" | "Unstable";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
        /** Override the Intercom-Version header */
        version?: "1.0" | "1.1" | "1.2" | "1.3" | "1.4" | "2.0" | "2.1" | "2.2" | "2.3" | "2.4" | "2.5" | "2.6" | "2.7" | "2.8" | "2.9" | "2.10" | "2.11" | "Unstable";
    }
}
/**
 * Everything about your contacts
 */
export declare class Contacts {
    protected readonly _options: Contacts.Options;
    constructor(_options?: Contacts.Options);
    /**
     * You can fetch a list of companies that are associated to a contact.
     *
     * @param {Intercom.ListAttachedCompaniesRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.contacts.listAttachedCompanies({
     *         contact_id: "63a07ddf05a32042dffac965"
     *     })
     */
    listAttachedCompanies(request: Intercom.ListAttachedCompaniesRequest, requestOptions?: Contacts.RequestOptions): Promise<core.Page<Intercom.Company>>;
    /**
     * You can fetch a list of segments that are associated to a contact.
     *
     * @param {Intercom.ListSegmentsAttachedToContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.contacts.listAttachedSegments({
     *         contact_id: "63a07ddf05a32042dffac965"
     *     })
     */
    listAttachedSegments(request: Intercom.ListSegmentsAttachedToContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.ContactSegments>;
    /**
     * You can fetch a list of subscription types that are attached to a contact. These can be subscriptions that a user has 'opted-in' to or has 'opted-out' from, depending on the subscription type.
     * This will return a list of Subscription Type objects that the contact is associated with.
     *
     * The data property will show a combined list of:
     *
     *   1.Opt-out subscription types that the user has opted-out from.
     *   2.Opt-in subscription types that the user has opted-in to receiving.
     *
     * @param {Intercom.ListAttachedSubscriptionsRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.contacts.listAttachedSubscriptions({
     *         contact_id: "63a07ddf05a32042dffac965"
     *     })
     */
    listAttachedSubscriptions(request: Intercom.ListAttachedSubscriptionsRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.SubscriptionTypeList>;
    /**
     * You can add a specific subscription to a contact. In Intercom, we have two different subscription types based on user consent - opt-out and opt-in:
     *
     *   1.Attaching a contact to an opt-out subscription type will opt that user out from receiving messages related to that subscription type.
     *
     *   2.Attaching a contact to an opt-in subscription type will opt that user in to receiving messages related to that subscription type.
     *
     * This will return a subscription type model for the subscription type that was added to the contact.
     *
     * @param {Intercom.AttachSubscriptionToContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.contacts.attachSubscription({
     *         contact_id: "63a07ddf05a32042dffac965",
     *         id: "37846",
     *         consent_type: "opt_in"
     *     })
     *
     * @example
     *     await client.contacts.attachSubscription({
     *         contact_id: "63a07ddf05a32042dffac965",
     *         id: "invalid_id",
     *         consent_type: "opt_in"
     *     })
     */
    attachSubscription(request: Intercom.AttachSubscriptionToContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.SubscriptionType>;
    /**
     * You can remove a specific subscription from a contact. This will return a subscription type model for the subscription type that was removed from the contact.
     *
     * @param {Intercom.DetachSubscriptionFromContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.contacts.detachSubscription({
     *         contact_id: "63a07ddf05a32042dffac965",
     *         subscription_id: "37846"
     *     })
     */
    detachSubscription(request: Intercom.DetachSubscriptionFromContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.SubscriptionType>;
    /**
     * You can fetch a list of all tags that are attached to a specific contact.
     *
     * @param {Intercom.ListTagsAttachedToContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.contacts.listAttachedTags({
     *         contact_id: "63a07ddf05a32042dffac965"
     *     })
     */
    listAttachedTags(request: Intercom.ListTagsAttachedToContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.TagList>;
    /**
     * You can fetch the details of a single contact.
     *
     * @param {Intercom.FindContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     *
     * @example
     *     await client.contacts.find({
     *         contact_id: "63a07ddf05a32042dffac965"
     *     })
     */
    find(request: Intercom.FindContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.Contact>;
    /**
     * You can update an existing contact (ie. user or lead).
     *
     * @param {Intercom.UpdateContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     *
     * @example
     *     await client.contacts.update({
     *         contact_id: "63a07ddf05a32042dffac965",
     *         email: "joebloggs@intercom.io",
     *         name: "joe bloggs"
     *     })
     */
    update(request: Intercom.UpdateContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.Contact>;
    /**
     * You can delete a single contact.
     *
     * @param {Intercom.DeleteContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     *
     * @example
     *     await client.contacts.delete({
     *         contact_id: "contact_id"
     *     })
     */
    delete(request: Intercom.DeleteContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.ContactDeleted>;
    /**
     * You can merge a contact with a `role` of `lead` into a contact with a `role` of `user`.
     *
     * @param {Intercom.MergeContactsRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     *
     * @example
     *     await client.contacts.mergeLeadInUser({
     *         from: "667d60ac8a68186f43bafdbb",
     *         into: "667d60ac8a68186f43bafdbc"
     *     })
     */
    mergeLeadInUser(request: Intercom.MergeContactsRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.Contact>;
    /**
     * You can search for multiple contacts by the value of their attributes in order to fetch exactly who you want.
     *
     * To search for contacts, you need to send a `POST` request to `https://api.intercom.io/contacts/search`.
     *
     * This will accept a query object in the body which will define your filters in order to search for contacts.
     *
     * {% admonition type="warning" name="Optimizing search queries" %}
     *   Search queries can be complex, so optimizing them can help the performance of your search.
     *   Use the `AND` and `OR` operators to combine multiple filters to get the exact results you need and utilize
     *   pagination to limit the number of results returned. The default is `50` results per page.
     *   See the [pagination section](https://developers.intercom.com/docs/build-an-integration/learn-more/rest-apis/pagination/#example-search-conversations-request) for more details on how to use the `starting_after` param.
     * {% /admonition %}
     * ### Contact Creation Delay
     *
     * If a contact has recently been created, there is a possibility that it will not yet be available when searching. This means that it may not appear in the response. This delay can take a few minutes. If you need to be instantly notified it is recommended to use webhooks and iterate to see if they match your search filters.
     *
     * ### Nesting & Limitations
     *
     * You can nest these filters in order to get even more granular insights that pinpoint exactly what you need. Example: (1 OR 2) AND (3 OR 4).
     * There are some limitations to the amount of multiple's there can be:
     * * There's a limit of max 2 nested filters
     * * There's a limit of max 15 filters for each AND or OR group
     *
     * ### Searching for Timestamp Fields
     *
     * All timestamp fields (created_at, updated_at etc.) are indexed as Dates for Contact Search queries; Datetime queries are not currently supported. This means you can only query for timestamp fields by day - not hour, minute or second.
     * For example, if you search for all Contacts with a created_at value greater (>) than 1577869200 (the UNIX timestamp for January 1st, 2020 9:00 AM), that will be interpreted as 1577836800 (January 1st, 2020 12:00 AM). The search results will then include Contacts created from January 2nd, 2020 12:00 AM onwards.
     * If you'd like to get contacts created on January 1st, 2020 you should search with a created_at value equal (=) to 1577836800 (January 1st, 2020 12:00 AM).
     * This behaviour applies only to timestamps used in search queries. The search results will still contain the full UNIX timestamp and be sorted accordingly.
     *
     * ### Accepted Fields
     *
     * Most key listed as part of the Contacts Model are searchable, whether writeable or not. The value you search for has to match the accepted type, otherwise the query will fail (ie. as `created_at` accepts a date, the `value` cannot be a string such as `"foorbar"`).
     *
     * | Field                              | Type                           |
     * | ---------------------------------- | ------------------------------ |
     * | id                                 | String                         |
     * | role                               | String<br>Accepts user or lead |
     * | name                               | String                         |
     * | avatar                             | String                         |
     * | owner_id                           | Integer                        |
     * | email                              | String                         |
     * | email_domain                       | String                         |
     * | phone                              | String                         |
     * | external_id                        | String                         |
     * | created_at                         | Date (UNIX Timestamp)          |
     * | signed_up_at                       | Date (UNIX Timestamp)          |
     * | updated_at                         | Date (UNIX Timestamp)          |
     * | last_seen_at                       | Date (UNIX Timestamp)          |
     * | last_contacted_at                  | Date (UNIX Timestamp)          |
     * | last_replied_at                    | Date (UNIX Timestamp)          |
     * | last_email_opened_at               | Date (UNIX Timestamp)          |
     * | last_email_clicked_at              | Date (UNIX Timestamp)          |
     * | language_override                  | String                         |
     * | browser                            | String                         |
     * | browser_language                   | String                         |
     * | os                                 | String                         |
     * | location.country                   | String                         |
     * | location.region                    | String                         |
     * | location.city                      | String                         |
     * | unsubscribed_from_emails           | Boolean                        |
     * | marked_email_as_spam               | Boolean                        |
     * | has_hard_bounced                   | Boolean                        |
     * | ios_last_seen_at                   | Date (UNIX Timestamp)          |
     * | ios_app_version                    | String                         |
     * | ios_device                         | String                         |
     * | ios_app_device                     | String                         |
     * | ios_os_version                     | String                         |
     * | ios_app_name                       | String                         |
     * | ios_sdk_version                    | String                         |
     * | android_last_seen_at               | Date (UNIX Timestamp)          |
     * | android_app_version                | String                         |
     * | android_device                     | String                         |
     * | android_app_name                   | String                         |
     * | andoid_sdk_version                 | String                         |
     * | segment_id                         | String                         |
     * | tag_id                             | String                         |
     * | custom_attributes.{attribute_name} | String                         |
     *
     * ### Accepted Operators
     *
     * {% admonition type="warning" name="Searching based on `created_at`" %}
     *   You cannot use the `<=` or `>=` operators to search by `created_at`.
     * {% /admonition %}
     *
     * The table below shows the operators you can use to define how you want to search for the value.  The operator should be put in as a string (`"="`). The operator has to be compatible with the field's type (eg. you cannot search with `>` for a given string value as it's only compatible for integer's and dates).
     *
     * | Operator | Valid Types                      | Description                                                      |
     * | :------- | :------------------------------- | :--------------------------------------------------------------- |
     * | =        | All                              | Equals                                                           |
     * | !=       | All                              | Doesn't Equal                                                    |
     * | IN       | All                              | In<br>Shortcut for `OR` queries<br>Values must be in Array       |
     * | NIN      | All                              | Not In<br>Shortcut for `OR !` queries<br>Values must be in Array |
     * | >        | Integer<br>Date (UNIX Timestamp) | Greater than                                                     |
     * | <       | Integer<br>Date (UNIX Timestamp) | Lower than                                                       |
     * | ~        | String                           | Contains                                                         |
     * | !~       | String                           | Doesn't Contain                                                  |
     * | ^        | String                           | Starts With                                                      |
     * | $        | String                           | Ends With                                                        |
     *
     * @param {Intercom.SearchRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     *
     * @example
     *     await client.contacts.search({
     *         query: {
     *             operator: "AND",
     *             value: [{
     *                     field: "created_at",
     *                     operator: ">",
     *                     value: "1306054154"
     *                 }]
     *         },
     *         pagination: {
     *             per_page: 5
     *         }
     *     })
     */
    search(request: Intercom.SearchRequest, requestOptions?: Contacts.RequestOptions): Promise<core.Page<Intercom.Contact>>;
    /**
     * You can fetch a list of all contacts (ie. users or leads) in your workspace.
     * {% admonition type="warning" name="Pagination" %}
     *   You can use pagination to limit the number of results returned. The default is `50` results per page.
     *   See the [pagination section](https://developers.intercom.com/docs/build-an-integration/learn-more/rest-apis/pagination/#pagination-for-list-apis) for more details on how to use the `starting_after` param.
     * {% /admonition %}
     *
     * @param {Intercom.ListContactsRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     *
     * @example
     *     await client.contacts.list()
     */
    list(request?: Intercom.ListContactsRequest, requestOptions?: Contacts.RequestOptions): Promise<core.Page<Intercom.Contact>>;
    /**
     * You can create a new contact (ie. user or lead).
     *
     * @param {Intercom.CreateContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     *
     * @example
     *     await client.contacts.create({
     *         email: "joebloggs@intercom.io"
     *     })
     */
    create(request: Intercom.CreateContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.Contact>;
    /**
     * You can archive a single contact.
     *
     * @param {Intercom.ArchiveContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.contacts.archive({
     *         contact_id: "63a07ddf05a32042dffac965"
     *     })
     */
    archive(request: Intercom.ArchiveContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.ContactArchived>;
    /**
     * You can unarchive a single contact.
     *
     * @param {Intercom.UnarchiveContactRequest} request
     * @param {Contacts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.contacts.unarchive({
     *         contact_id: "63a07ddf05a32042dffac965"
     *     })
     */
    unarchive(request: Intercom.UnarchiveContactRequest, requestOptions?: Contacts.RequestOptions): Promise<Intercom.ContactUnarchived>;
    protected _getAuthorizationHeader(): Promise<string>;
}
