/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Intercom from "../../../index";
export declare namespace Conversations {
    interface Options {
        environment?: core.Supplier<environments.IntercomEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        token?: core.Supplier<core.BearerToken | undefined>;
        /** Override the Intercom-Version header */
        version?: "1.0" | "1.1" | "1.2" | "1.3" | "1.4" | "2.0" | "2.1" | "2.2" | "2.3" | "2.4" | "2.5" | "2.6" | "2.7" | "2.8" | "2.9" | "2.10" | "2.11" | "Unstable";
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
        /** Override the Intercom-Version header */
        version?: "1.0" | "1.1" | "1.2" | "1.3" | "1.4" | "2.0" | "2.1" | "2.2" | "2.3" | "2.4" | "2.5" | "2.6" | "2.7" | "2.8" | "2.9" | "2.10" | "2.11" | "Unstable";
    }
}
/**
 * Everything about your Conversations
 */
export declare class Conversations {
    protected readonly _options: Conversations.Options;
    constructor(_options?: Conversations.Options);
    /**
     * You can fetch a list of all conversations.
     *
     * You can optionally request the result page size and the cursor to start after to fetch the result.
     * {% admonition type="warning" name="Pagination" %}
     *   You can use pagination to limit the number of results returned. The default is `20` results per page.
     *   See the [pagination section](https://developers.intercom.com/docs/build-an-integration/learn-more/rest-apis/pagination/#pagination-for-list-apis) for more details on how to use the `starting_after` param.
     * {% /admonition %}
     *
     * @param {Intercom.ListConversationsRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     *
     * @example
     *     await client.conversations.list()
     */
    list(request?: Intercom.ListConversationsRequest, requestOptions?: Conversations.RequestOptions): Promise<core.Page<Intercom.Conversation>>;
    /**
     * You can create a conversation that has been initiated by a contact (ie. user or lead).
     * The conversation can be an in-app message only.
     *
     * {% admonition type="info" name="Sending for visitors" %}
     * You can also send a message from a visitor by specifying their `user_id` or `id` value in the `from` field, along with a `type` field value of `contact`.
     * This visitor will be automatically converted to a contact with a lead role once the conversation is created.
     * {% /admonition %}
     *
     * This will return the Message model that has been created.
     *
     * @param {Intercom.CreateConversationRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.conversations.create({
     *         from: {
     *             type: "user",
     *             id: "667d60d18a68186f43bafddd"
     *         },
     *         body: "Hello there"
     *     })
     *
     * @example
     *     await client.conversations.create({
     *         from: {
     *             type: "user",
     *             id: "123_doesnt_exist"
     *         },
     *         body: "Hello there"
     *     })
     */
    create(request: Intercom.CreateConversationRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Message>;
    /**
     *
     * You can fetch the details of a single conversation.
     *
     * This will return a single Conversation model with all its conversation parts.
     *
     * {% admonition type="warning" name="Hard limit of 500 parts" %}
     * The maximum number of conversation parts that can be returned via the API is 500. If you have more than that we will return the 500 most recent conversation parts.
     * {% /admonition %}
     *
     * For AI agent conversation metadata, please note that you need to have the agent enabled in your workspace, which is a [paid feature](https://www.intercom.com/help/en/articles/8205718-fin-resolutions#h_97f8c2e671).
     *
     * @param {Intercom.FindConversationRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.conversations.find({
     *         conversation_id: "123",
     *         display_as: "plaintext"
     *     })
     */
    find(request: Intercom.FindConversationRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Conversation>;
    /**
     *
     * You can update an existing conversation.
     *
     * {% admonition type="info" name="Replying and other actions" %}
     * If you want to reply to a coveration or take an action such as assign, unassign, open, close or snooze, take a look at the reply and manage endpoints.
     * {% /admonition %}
     *
     * @param {Intercom.UpdateConversationRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.conversations.update({
     *         conversation_id: "123",
     *         display_as: "plaintext",
     *         read: true,
     *         custom_attributes: {
     *             "issue_type": "Billing",
     *             "priority": "High"
     *         }
     *     })
     */
    update(request: Intercom.UpdateConversationRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Conversation>;
    /**
     * You can search for multiple conversations by the value of their attributes in order to fetch exactly which ones you want.
     *
     * To search for conversations, you need to send a `POST` request to `https://api.intercom.io/conversations/search`.
     *
     * This will accept a query object in the body which will define your filters in order to search for conversations.
     * {% admonition type="warning" name="Optimizing search queries" %}
     *   Search queries can be complex, so optimizing them can help the performance of your search.
     *   Use the `AND` and `OR` operators to combine multiple filters to get the exact results you need and utilize
     *   pagination to limit the number of results returned. The default is `20` results per page and maximum is `150`.
     *   See the [pagination section](https://developers.intercom.com/docs/build-an-integration/learn-more/rest-apis/pagination/#example-search-conversations-request) for more details on how to use the `starting_after` param.
     * {% /admonition %}
     *
     * ### Nesting & Limitations
     *
     * You can nest these filters in order to get even more granular insights that pinpoint exactly what you need. Example: (1 OR 2) AND (3 OR 4).
     * There are some limitations to the amount of multiple's there can be:
     * - There's a limit of max 2 nested filters
     * - There's a limit of max 15 filters for each AND or OR group
     *
     * ### Accepted Fields
     *
     * Most keys listed as part of the The conversation model is searchable, whether writeable or not. The value you search for has to match the accepted type, otherwise the query will fail (ie. as `created_at` accepts a date, the `value` cannot be a string such as `"foorbar"`).
     * The `source.body` field is unique as the search will not be performed against the entire value, but instead against every element of the value separately. For example, when searching for a conversation with a `"I need support"` body - the query should contain a `=` operator with the value `"support"` for such conversation to be returned. A query with a `=` operator and a `"need support"` value will not yield a result.
     *
     * | Field                                     | Type                                                                                                                                                   |
     * | :---------------------------------------- | :----------------------------------------------------------------------------------------------------------------------------------------------------- |
     * | id                                        | String                                                                                                                                                 |
     * | created_at                                | Date (UNIX timestamp)                                                                                                                                  |
     * | updated_at                                | Date (UNIX timestamp)                                                                                                                                  |
     * | source.type                               | String<br>Accepted fields are `conversation`, `email`, `facebook`, `instagram`, `phone_call`, `phone_switch`, `push`, `sms`, `twitter` and `whatsapp`. |
     * | source.id                                 | String                                                                                                                                                 |
     * | source.delivered_as                       | String                                                                                                                                                 |
     * | source.subject                            | String                                                                                                                                                 |
     * | source.body                               | String                                                                                                                                                 |
     * | source.author.id                          | String                                                                                                                                                 |
     * | source.author.type                        | String                                                                                                                                                 |
     * | source.author.name                        | String                                                                                                                                                 |
     * | source.author.email                       | String                                                                                                                                                 |
     * | source.url                                | String                                                                                                                                                 |
     * | contact_ids                               | String                                                                                                                                                 |
     * | teammate_ids                              | String                                                                                                                                                 |
     * | admin_assignee_id                         | String                                                                                                                                                 |
     * | team_assignee_id                          | String                                                                                                                                                 |
     * | channel_initiated                         | String                                                                                                                                                 |
     * | open                                      | Boolean                                                                                                                                                |
     * | read                                      | Boolean                                                                                                                                                |
     * | state                                     | String                                                                                                                                                 |
     * | waiting_since                             | Date (UNIX timestamp)                                                                                                                                  |
     * | snoozed_until                             | Date (UNIX timestamp)                                                                                                                                  |
     * | tag_ids                                   | String                                                                                                                                                 |
     * | priority                                  | String                                                                                                                                                 |
     * | statistics.time_to_assignment             | Integer                                                                                                                                                |
     * | statistics.time_to_admin_reply            | Integer                                                                                                                                                |
     * | statistics.time_to_first_close            | Integer                                                                                                                                                |
     * | statistics.time_to_last_close             | Integer                                                                                                                                                |
     * | statistics.median_time_to_reply           | Integer                                                                                                                                                |
     * | statistics.first_contact_reply_at         | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.first_assignment_at            | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.first_admin_reply_at           | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.first_close_at                 | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.last_assignment_at             | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.last_assignment_admin_reply_at | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.last_contact_reply_at          | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.last_admin_reply_at            | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.last_close_at                  | Date (UNIX timestamp)                                                                                                                                  |
     * | statistics.last_closed_by_id              | String                                                                                                                                                 |
     * | statistics.count_reopens                  | Integer                                                                                                                                                |
     * | statistics.count_assignments              | Integer                                                                                                                                                |
     * | statistics.count_conversation_parts       | Integer                                                                                                                                                |
     * | conversation_rating.requested_at          | Date (UNIX timestamp)                                                                                                                                  |
     * | conversation_rating.replied_at            | Date (UNIX timestamp)                                                                                                                                  |
     * | conversation_rating.score                 | Integer                                                                                                                                                |
     * | conversation_rating.remark                | String                                                                                                                                                 |
     * | conversation_rating.contact_id            | String                                                                                                                                                 |
     * | conversation_rating.admin_d               | String                                                                                                                                                 |
     * | ai_agent_participated                     | Boolean                                                                                                                                                |
     * | ai_agent.resolution_state                 | String                                                                                                                                                 |
     * | ai_agent.last_answer_type                 | String                                                                                                                                                 |
     * | ai_agent.rating                           | Integer                                                                                                                                                |
     * | ai_agent.rating_remark                    | String                                                                                                                                                 |
     * | ai_agent.source_type                      | String                                                                                                                                                 |
     * | ai_agent.source_title                     | String                                                                                                                                                 |
     *
     * ### Accepted Operators
     *
     * The table below shows the operators you can use to define how you want to search for the value.  The operator should be put in as a string (`"="`). The operator has to be compatible with the field's type  (eg. you cannot search with `>` for a given string value as it's only compatible for integer's and dates).
     *
     * | Operator | Valid Types                    | Description                                                  |
     * | :------- | :----------------------------- | :----------------------------------------------------------- |
     * | =        | All                            | Equals                                                       |
     * | !=       | All                            | Doesn't Equal                                                |
     * | IN       | All                            | In  Shortcut for `OR` queries  Values most be in Array       |
     * | NIN      | All                            | Not In  Shortcut for `OR !` queries  Values must be in Array |
     * | >        | Integer  Date (UNIX Timestamp) | Greater (or equal) than                                      |
     * | <       | Integer  Date (UNIX Timestamp) | Lower (or equal) than                                        |
     * | ~        | String                         | Contains                                                     |
     * | !~       | String                         | Doesn't Contain                                              |
     * | ^        | String                         | Starts With                                                  |
     * | $        | String                         | Ends With                                                    |
     *
     * @param {Intercom.SearchRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @example
     *     await client.conversations.search({
     *         query: {
     *             operator: "AND",
     *             value: [{
     *                     field: "created_at",
     *                     operator: ">",
     *                     value: "1306054154"
     *                 }]
     *         },
     *         pagination: {
     *             per_page: 5
     *         }
     *     })
     */
    search(request: Intercom.SearchRequest, requestOptions?: Conversations.RequestOptions): Promise<core.Page<Intercom.Conversation>>;
    /**
     * You can reply to a conversation with a message from an admin or on behalf of a contact, or with a note for admins.
     *
     * @param {Intercom.ReplyToConversationRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.conversations.reply({
     *         conversation_id: "123 or \"last\"",
     *         body: {
     *             message_type: "comment",
     *             type: "user",
     *             body: "Thanks again :)",
     *             intercom_user_id: "667d60f18a68186f43bafdf4"
     *         }
     *     })
     *
     * @example
     *     await client.conversations.reply({
     *         conversation_id: "123 or \"last\"",
     *         body: {
     *             message_type: "note",
     *             type: "admin",
     *             body: "<html> <body>  <h2>An Unordered HTML List</h2>  <ul>   <li>Coffee</li>   <li>Tea</li>   <li>Milk</li> </ul>    <h2>An Ordered HTML List</h2>  <ol>   <li>Coffee</li>   <li>Tea</li>   <li>Milk</li> </ol>   </body> </html>",
     *             admin_id: "3156780"
     *         }
     *     })
     *
     * @example
     *     await client.conversations.reply({
     *         conversation_id: "123 or \"last\"",
     *         body: {
     *             message_type: "comment",
     *             type: "user",
     *             body: "Thanks again :)",
     *             intercom_user_id: "667d60f78a68186f43bafdf7"
     *         }
     *     })
     *
     * @example
     *     await client.conversations.reply({
     *         conversation_id: "123 or \"last\"",
     *         body: {
     *             message_type: "comment",
     *             type: "user",
     *             body: "Thanks again :)",
     *             intercom_user_id: "667d60f98a68186f43bafdf8"
     *         }
     *     })
     */
    reply(request: Intercom.ReplyToConversationRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Conversation>;
    /**
     * For managing conversations you can:
     * - Close a conversation
     * - Snooze a conversation to reopen on a future date
     * - Open a conversation which is `snoozed` or `closed`
     * - Assign a conversation to an admin and/or team.
     *
     * @param {Intercom.ManageConversationPartsRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.conversations.manage({
     *         conversation_id: "123",
     *         body: {
     *             message_type: "close",
     *             type: "admin",
     *             admin_id: "12345"
     *         }
     *     })
     *
     * @example
     *     await client.conversations.manage({
     *         conversation_id: "123",
     *         body: {
     *             message_type: "snoozed",
     *             admin_id: "5017691",
     *             snoozed_until: 1673609604
     *         }
     *     })
     *
     * @example
     *     await client.conversations.manage({
     *         conversation_id: "123",
     *         body: {
     *             message_type: "open",
     *             admin_id: "5017690"
     *         }
     *     })
     *
     * @example
     *     await client.conversations.manage({
     *         conversation_id: "123",
     *         body: {
     *             message_type: "assignment",
     *             type: "admin",
     *             admin_id: "12345",
     *             assignee_id: "4324241"
     *         }
     *     })
     */
    manage(request: Intercom.ManageConversationPartsRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Conversation>;
    /**
     * {% admonition type="danger" name="Deprecation of Run Assignment Rules" %}
     * Run assignment rules is now deprecated in version 2.12 and future versions and will be permanently removed on December 31, 2026. After this date, any requests made to this endpoint will fail.
     * {% /admonition %}
     * You can let a conversation be automatically assigned following assignment rules.
     * {% admonition type="warning" name="When using workflows" %}
     * It is not possible to use this endpoint with Workflows.
     * {% /admonition %}
     *
     * @param {Intercom.AutoAssignConversationRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.conversations.runAssignmentRules({
     *         conversation_id: "123"
     *     })
     */
    runAssignmentRules(request: Intercom.AutoAssignConversationRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Conversation>;
    /**
     * You can add participants who are contacts to a conversation, on behalf of either another contact or an admin.
     *
     * {% admonition type="warning" name="Contacts without an email" %}
     * If you add a contact via the email parameter and there is no user/lead found on that workspace with he given email, then we will create a new contact with `role` set to `lead`.
     * {% /admonition %}
     *
     * @param {Intercom.AttachContactToConversationRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.conversations.attachContactAsAdmin({
     *         conversation_id: "123",
     *         admin_id: "12345",
     *         customer: {
     *             intercom_user_id: "667d61168a68186f43bafe0d"
     *         }
     *     })
     *
     * @example
     *     await client.conversations.attachContactAsAdmin({
     *         conversation_id: "123",
     *         admin_id: "12345",
     *         customer: {
     *             intercom_user_id: "667d61188a68186f43bafe0e"
     *         }
     *     })
     */
    attachContactAsAdmin(request: Intercom.AttachContactToConversationRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Conversation>;
    /**
     * You can add participants who are contacts to a conversation, on behalf of either another contact or an admin.
     *
     * {% admonition type="warning" name="Contacts without an email" %}
     * If you add a contact via the email parameter and there is no user/lead found on that workspace with he given email, then we will create a new contact with `role` set to `lead`.
     * {% /admonition %}
     *
     * @param {Intercom.DetachContactFromConversationRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.ForbiddenError}
     * @throws {@link Intercom.NotFoundError}
     * @throws {@link Intercom.UnprocessableEntityError}
     *
     * @example
     *     await client.conversations.detachContactAsAdmin({
     *         conversation_id: "123",
     *         contact_id: "123",
     *         admin_id: "5017690"
     *     })
     */
    detachContactAsAdmin(request: Intercom.DetachContactFromConversationRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Conversation>;
    /**
     * You can redact a conversation part or the source message of a conversation (as seen in the source object).
     *
     * {% admonition type="info" name="Redacting parts and messages" %}
     * If you are redacting a conversation part, it must have a `body`. If you are redacting a source message, it must have been created by a contact. We will return a `conversation_part_not_redactable` error if these criteria are not met.
     * {% /admonition %}
     *
     * @param {Intercom.RedactConversationRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.UnauthorizedError}
     * @throws {@link Intercom.NotFoundError}
     *
     * @example
     *     await client.conversations.redactConversationPart({
     *         type: "conversation_part",
     *         conversation_id: "19894788788",
     *         conversation_part_id: "19381789428"
     *     })
     *
     * @example
     *     await client.conversations.redactConversationPart({
     *         type: "conversation_part",
     *         conversation_id: "really_123_doesnt_exist",
     *         conversation_part_id: "really_123_doesnt_exist"
     *     })
     */
    redactConversationPart(request: Intercom.RedactConversationRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Conversation>;
    /**
     * You can convert a conversation to a ticket.
     *
     * @param {Intercom.ConvertConversationToTicketRequest} request
     * @param {Conversations.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Intercom.BadRequestError}
     *
     * @example
     *     await client.conversations.convertToTicket({
     *         conversation_id: "123",
     *         ticket_type_id: "79"
     *     })
     *
     * @example
     *     await client.conversations.convertToTicket({
     *         conversation_id: "123",
     *         ticket_type_id: "80"
     *     })
     */
    convertToTicket(request: Intercom.ConvertConversationToTicketRequest, requestOptions?: Conversations.RequestOptions): Promise<Intercom.Ticket>;
    protected _getAuthorizationHeader(): Promise<string>;
}
